@@ -84,14 +84,14 @@ class Yolov7DetectionModel:
                         label = f"Id:{track_id} {category_name} {float(score):.2f}"
 
                         if self.save or self.show:
-                            frame = video_vis(
+                            img_src = video_vis(
                                 bbox=bbox,
                                 label=label,
                                 frame=img_src,
                                 object_id=int(category_id),
                             )
                     if self.save:
-                        video_writer.write(frame)
+                        video_writer.write(img_src)
 
                 else:
                     for pred in prediction.cpu().detach().numpy():
